aboutsummaryrefslogtreecommitdiff
path: root/ShiftOS_TheReturn
diff options
context:
space:
mode:
authorwilliam341 <[email protected]>2017-07-27 16:34:27 -0700
committerwilliam341 <[email protected]>2017-07-27 16:34:27 -0700
commit18079c6f43981f1bf9fc093b3c5b68873fe90348 (patch)
tree7be93f2caeaca5208a02be627cb50d36e718cad1 /ShiftOS_TheReturn
parent86dde20529e926ee75af2b1e3a574f6729bd8771 (diff)
downloadshiftos_thereturn-18079c6f43981f1bf9fc093b3c5b68873fe90348.tar.gz
shiftos_thereturn-18079c6f43981f1bf9fc093b3c5b68873fe90348.tar.bz2
shiftos_thereturn-18079c6f43981f1bf9fc093b3c5b68873fe90348.zip
hacking p1
Diffstat (limited to 'ShiftOS_TheReturn')
-rw-r--r--ShiftOS_TheReturn/GUI/FileSkimmerBackend.cs (renamed from ShiftOS_TheReturn/FileSkimmerBackend.cs)0
-rw-r--r--ShiftOS_TheReturn/GUI/IShiftOSWindow.cs (renamed from ShiftOS_TheReturn/IShiftOSWindow.cs)0
-rw-r--r--ShiftOS_TheReturn/GUI/IStatusIcon.cs (renamed from ShiftOS_TheReturn/IStatusIcon.cs)0
-rw-r--r--ShiftOS_TheReturn/GUI/OutOfBoxExperience.cs (renamed from ShiftOS_TheReturn/OutOfBoxExperience.cs)0
-rw-r--r--ShiftOS_TheReturn/GUI/Skinning.cs (renamed from ShiftOS_TheReturn/Skinning.cs)0
-rw-r--r--ShiftOS_TheReturn/GUI/TutorialManager.cs (renamed from ShiftOS_TheReturn/TutorialManager.cs)0
-rw-r--r--ShiftOS_TheReturn/GUI/WinOpenAttribute.cs (renamed from ShiftOS_TheReturn/WinOpenAttribute.cs)0
-rw-r--r--ShiftOS_TheReturn/Hacking.cs23
8 files changed, 21 insertions, 2 deletions
diff --git a/ShiftOS_TheReturn/FileSkimmerBackend.cs b/ShiftOS_TheReturn/GUI/FileSkimmerBackend.cs
index b14733f..b14733f 100644
--- a/ShiftOS_TheReturn/FileSkimmerBackend.cs
+++ b/ShiftOS_TheReturn/GUI/FileSkimmerBackend.cs
diff --git a/ShiftOS_TheReturn/IShiftOSWindow.cs b/ShiftOS_TheReturn/GUI/IShiftOSWindow.cs
index e4a5a21..e4a5a21 100644
--- a/ShiftOS_TheReturn/IShiftOSWindow.cs
+++ b/ShiftOS_TheReturn/GUI/IShiftOSWindow.cs
diff --git a/ShiftOS_TheReturn/IStatusIcon.cs b/ShiftOS_TheReturn/GUI/IStatusIcon.cs
index f32d1c1..f32d1c1 100644
--- a/ShiftOS_TheReturn/IStatusIcon.cs
+++ b/ShiftOS_TheReturn/GUI/IStatusIcon.cs
diff --git a/ShiftOS_TheReturn/OutOfBoxExperience.cs b/ShiftOS_TheReturn/GUI/OutOfBoxExperience.cs
index eb8e61d..eb8e61d 100644
--- a/ShiftOS_TheReturn/OutOfBoxExperience.cs
+++ b/ShiftOS_TheReturn/GUI/OutOfBoxExperience.cs
diff --git a/ShiftOS_TheReturn/Skinning.cs b/ShiftOS_TheReturn/GUI/Skinning.cs
index d8549f6..d8549f6 100644
--- a/ShiftOS_TheReturn/Skinning.cs
+++ b/ShiftOS_TheReturn/GUI/Skinning.cs
diff --git a/ShiftOS_TheReturn/TutorialManager.cs b/ShiftOS_TheReturn/GUI/TutorialManager.cs
index 13df153..13df153 100644
--- a/ShiftOS_TheReturn/TutorialManager.cs
+++ b/ShiftOS_TheReturn/GUI/TutorialManager.cs
diff --git a/ShiftOS_TheReturn/WinOpenAttribute.cs b/ShiftOS_TheReturn/GUI/WinOpenAttribute.cs
index c617360..c617360 100644
--- a/ShiftOS_TheReturn/WinOpenAttribute.cs
+++ b/ShiftOS_TheReturn/GUI/WinOpenAttribute.cs
diff --git a/ShiftOS_TheReturn/Hacking.cs b/ShiftOS_TheReturn/Hacking.cs
index 9ace50e..1e66f26 100644
--- a/ShiftOS_TheReturn/Hacking.cs
+++ b/ShiftOS_TheReturn/Hacking.cs
@@ -10,6 +10,8 @@ namespace ShiftOS.Engine
{
private static List<HackableSystem> _activeConnections = new List<HackableSystem>();
private static List<Objects.Hackable> Hackables = new List<Objects.Hackable>();
+ private static List<Objects.Exploit> Exploits = new List<Objects.Exploit>();
+ private static List<Objects.Payload> Payloads = new List<Objects.Payload>();
private static List<Objects.Loot> Loot = new List<Objects.Loot>();
public static HackableSystem CurrentHackable { get; private set; }
@@ -22,6 +24,21 @@ namespace ShiftOS.Engine
}
}
+ public static Objects.Exploit[] AvailableExploits
+ {
+ get
+ {
+ return Exploits.Where(x => Shiftorium.UpgradeInstalled(x.Dependencies) && !Shiftorium.UpgradeInstalled(x.ID)).ToArray();
+ }
+ }
+
+ public static Objects.Payload[] AvailablePayloads
+ {
+ get
+ {
+ return Payloads.Where(x => Shiftorium.UpgradeInstalled(x.Dependencies) && !Shiftorium.UpgradeInstalled(x.ID)).ToArray();
+ }
+ }
public static HackableSystem[] ActiveConnections
{
@@ -178,10 +195,10 @@ namespace ShiftOS.Engine
public class NaughtyDeveloperException : Exception
{
/// <summary>
/// Create a new instance of the <see cref="NaughtyDeveloperException"/>, with the specified message, which will cause Visual Studio to call the person who caused the exception a scrotem.
/// </summary>
/// <param name="message">The message you want to yell at the user.</param>
- public NaughtyDeveloperException(string message) : base(message + " - FIX IT, YOU SCROTEM")
+ public NaughtyDeveloperException(string message) : base(message + " - FIX IT, YOU SCROTUM")
{
}
@@ -198,6 +215,8 @@ namespace ShiftOS.Engine
public interface IHackableProvider
{
Objects.Hackable[] GetHackables();
+ Objects.Exploit[] GetExploits();
+ Objects.Payload[] GetPayloads();
Objects.LootInfo[] GetLootInfo();
byte[] GetLootFromResource(string resId);
}
@@ -178,10 +195,10 @@ namespace ShiftOS.Engine
{
/// <summary>
- /// Create a new instance of the <see cref="NaughtyDeveloperException"/>, with the specified message, which will cause Visual Studio to call the person who caused the exception a scrotem.
+ /// Create a new instance of the <see cref="NaughtyDeveloperException"/>, with the specified message, which will cause Visual Studio to call the person who caused the exception a scrotum.
/// </summary>
/// <param name="message">The message you want to yell at the user.</param>